.. _twobody_api:

Two-body Module API
===================

This section provides the API documentation for the twobody submodules of astrodynx.

Two-body Integrals
------------------

.. automodule:: astrodynx.twobody.orb_integrals
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Kepler Equation
---------------

.. automodule:: astrodynx.twobody.kepler_equation
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
